<?php

namespace Drupal\global_node_translation\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Language\LanguageManagerInterface;

/**
 * Configure Translate Node settings.
 */
class GlobalNodeTranslationSettingsForm extends ConfigFormBase {

  /**
   * The language manager service.
   *
   * @var \Drupal\Core\Language\LanguageManagerInterface
   */
  protected $languageManager;

  /**
   * Constructs a new TranslateNodeSettingsForm object.
   *
   * @param \Drupal\Core\Language\LanguageManagerInterface $language_manager
   *   The language manager service.
   */
  public function __construct(LanguageManagerInterface $language_manager) {
    $this->languageManager = $language_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create($container) {
    return new static(
      $container->get('language_manager')
    );
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['global_node_translation.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'global_node_translation_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('global_node_translation.settings');

    // Get all enabled languages using the injected language manager.
    $languages = $this->languageManager->getLanguages();

    // Form element for selecting languages, excluding the default language.
    $form['enabled_languages'] = [
      '#type' => 'checkboxes',
      '#title' => $this->t('Select Languages for Translation'),
      '#options' => array_map(function ($language) {
        return $language->getName();
      }, $languages),
      '#default_value' => $config->get('enabled_languages') ?: [],
      '#description' => $this->t('Select the languages in which you want to create translations.'),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    // Save the selected languages in the configuration.
    $this->config('global_node_translation.settings')
      ->set('enabled_languages', array_filter($form_state->getValue('enabled_languages')))
      ->save();

    parent::submitForm($form, $form_state);
  }

}
